Exception: NoDefaultContentError

Inherits:
StandardError
  • Object
show all
Defined in:
app/models/content.rb

Instance Method Summary collapse

Constructor Details

#initialize(msg = "You must provide a default text for a content.") ⇒ NoDefaultContentError

Returns a new instance of NoDefaultContentError.



35
36
37
# File 'app/models/content.rb', line 35

def initialize(msg = "You must provide a default text for a content.")
  super(msg)
end