Exception: NoDefaultContentError
- Inherits:
-
StandardError
- Object
- StandardError
- NoDefaultContentError
- Defined in:
- app/models/content.rb
Instance Method Summary collapse
-
#initialize(msg = "You must provide a default text for a content.") ⇒ NoDefaultContentError
constructor
A new instance of NoDefaultContentError.
Constructor Details
#initialize(msg = "You must provide a default text for a content.") ⇒ NoDefaultContentError
Returns a new instance of NoDefaultContentError.
35 36 37 |
# File 'app/models/content.rb', line 35 def initialize(msg = "You must provide a default text for a content.") super(msg) end |